import numpy as np
import pygame

class Camera:
    def __init__ (self, screenMid):
        self.mid = screenMid
        self.zoom = 1 # zoom actuel
        self.lastZoom = 1.1 # dernier zoom
        self.position = np.array([0,0]) # position du point visé (ici le milieu de l'écran)

    def convertLocation (self, c1:np.array)->np.array: # Convertie les coordonnées de l'écran en coordonnées sur le jeu
        c2 = (c1 * self.zoom) + self.mid + (self.position * self.zoom)
        return c2

    def changeScreenLocation (self, c2:np.array)->np.array: # Convertie les coordonnées du jeu en coordonnées de l'écran
        c1 = (c2 - self.mid - (self.position / self.zoom)) / self.zoom
        return c1

    def zoomInOut (self, y): # Zoom en fonction de la molette
        self.lastZoom = self.zoom
        self.zoom += y*0.1

        self.zoom = np.clip(self.zoom, 0.3, 2) # zoom min max

    def setPosition (self, positionRelative): # Calcule la nouvelle position de l'écran
        newPos = self.position + positionRelative

        # Pour faire un carré (mur invisible) : 
        self.position = np.clip(newPos, [-1000, -1000], [1000, 1000])

        # Pour faire un cercle :
        #if np.linalg.norm(newPos) < RAYON_MUR_INVISIBLE:
            #self.position = newPos

    def __repr__ (self):
        return f"Zoom = {self.zoom}\nPosition = {self.position}\n"

    def scaleImage (self, img): # Change le zoom d'une image si nécessaire
        if self.zoom != self.lastZoom:
            return pygame.transform.scale(img, np.array(img.get_size())*self.zoom)

        return None
